@@ -40,12 +40,11 @@ class Dialect(metaclass=RegisteringMeta):
     def parser(self, **opts):
         return Parser(functions=self.functions, **opts)
 
-    def tokenizer(self, **opts):
+    def tokenizer(self):
         return Tokenizer(
             identifier=self.identifier,
             quotes=self.quotes,
             escape=self.escape,
-            **opts,
         )
 
     @classmethod
@@ -496,3 +495,7 @@ class SQLite(Dialect):
     transforms = {
         exp.TableSample: _no_tablesample_sql,
     }
+
+
+class Trino(Presto):
+    pass
