@@ -6,6 +6,9 @@ from sqlglot.helper import ensure_list, csv
 from sqlglot.tokens import Tokenizer
 
 
+logger = logging.getLogger("sqlglot")
+
+
 class Generator:
     """
     Generator interprets the given syntax tree and produces a SQL string as an output.
@@ -111,7 +114,7 @@ class Generator:
         for msg in self.unsupported_messages:
             if self.unsupported_level == ErrorLevel.RAISE:
                 raise UnsupportedError(msg)
-            logging.warning(msg)
+            logger.warning(msg)
 
         return sql
 
@@ -265,7 +268,7 @@ class Generator:
             if option
         )
 
-        return f"CREATE{temporary}{replace} {kind}{exists_sql} {this}{file_format}{expression_sql}{options}"
+        return f"CREATE{replace}{temporary} {kind}{exists_sql} {this}{file_format}{expression_sql}{options}"
 
     def cte_sql(self, expression):
         sql = ", ".join(
@@ -288,6 +291,12 @@ class Generator:
         exists_sql = " IF EXISTS " if expression.args.get("exists") else " "
         return f"DROP {kind}{exists_sql}{this}"
 
+    def except_sql(self, expression):
+        return self.set_operation(
+            expression,
+            f"EXCEPT{' DISTINCT' if expression.args.get('distinct') else ''}",
+        )
+
     def fileformat_sql(self, expression):
         if self.sql(expression, "this"):
             self.unsupported("File formats are not supported")
@@ -311,6 +320,12 @@ class Generator:
         expression_sql = self.sql(expression, "expression")
         return f"INSERT {kind} TABLE {this}{exists}{expression_sql}"
 
+    def intersect_sql(self, expression):
+        return self.set_operation(
+            expression,
+            f"INTERSECT{' DISTINCT' if expression.args.get('distinct') else ''}",
+        )
+
     def table_sql(self, expression):
         return ".".join(
             part
@@ -439,10 +454,9 @@ class Generator:
         return "*"
 
     def union_sql(self, expression):
-        this = self.sql(expression, "this")
-        op = self.seg(f"UNION{'' if expression.args['distinct'] else ' ALL'}")
-        expression = self.indent(self.sql(expression, "expression"), pad=0)
-        return f"{this}{op}{self.sep()}{expression}"
+        return self.set_operation(
+            expression, f"UNION{'' if expression.args.get('distinct') else ' ALL'}"
+        )
 
     def unnest_sql(self, expression):
         args = self.expressions(expression, flat=True)
@@ -692,3 +706,9 @@ class Generator:
         if flat:
             return f"{op} {expressions_sql}"
         return f"{self.seg(op)}{self.sep()}{expressions_sql}"
+
+    def set_operation(self, expression, op):
+        this = self.sql(expression, "this")
+        op = self.seg(op)
+        expression = self.indent(self.sql(expression, "expression"), pad=0)
+        return f"{this}{op}{self.sep()}{expression}"
