@@ -6,6 +6,9 @@ from sqlglot.tokens import Token, Tokenizer, TokenType
 import sqlglot.expressions as exp
 
 
+logger = logging.getLogger("sqlglot")
+
+
 class Parser:
     """
     Parser consumes a list of tokens produced by the :class:`~sqlglot.tokens.Tokenizer`
@@ -141,12 +144,23 @@ class Parser:
         TokenType.STAR: exp.Mul,
     }
 
+    TIMESTAMPS = {
+        TokenType.TIMESTAMP,
+        TokenType.TIMESTAMPTZ,
+    }
+
+    SET_OPERATIONS = {
+        TokenType.UNION,
+        TokenType.INTERSECT,
+        TokenType.EXCEPT,
+    }
+
     __slots__ = (
         "functions",
         "error_level",
         "error_message_context",
         "code",
-        "error",
+        "errors",
         "_tokens",
         "_chunks",
         "_index",
@@ -158,12 +172,12 @@ class Parser:
     def __init__(self, functions=None, error_level=None, error_message_context=None):
         self.functions = {**self.FUNCTIONS, **(functions or {})}
         self.error_level = error_level or ErrorLevel.RAISE
-        self.error_message_context = error_message_context or 50
+        self.error_message_context = error_message_context or 100
         self.reset()
 
     def reset(self):
         self.code = ""
-        self.error = None
+        self.errors = []
         self._tokens = []
         self._chunks = [[]]
         self._index = 0
@@ -205,6 +219,19 @@ class Parser:
             if self._index < len(self._tokens):
                 self.raise_error("Invalid expression / Unexpected token")
 
+            self.check_errors()
+            self.set_parents(expressions)
+
+        return expressions
+
+    def check_errors(self):
+        for error in self.errors:
+            if self.error_level == ErrorLevel.RAISE:
+                raise error
+            if self.error_level == ErrorLevel.WARN:
+                logger.error(error)
+
+    def set_parents(self, expressions):
         for expression in expressions:
             if not expression:
                 continue
@@ -213,8 +240,6 @@ class Parser:
                     node.parent = parent
                     node.arg_key = key
 
-        return expressions
-
     def raise_error(self, message, token=None):
         token = token or self._curr or self._prev or Token.string("")
         start = self._find_token(token, self.code)
@@ -222,14 +247,12 @@ class Parser:
         start_context = self.code[max(start - self.error_message_context, 0) : start]
         highlight = self.code[start:end]
         end_context = self.code[end : end + self.error_message_context]
-        self.error = ParseError(
-            f"{message}. Line {token.line}, Col: {token.col}.\n"
-            f"{start_context}\033[4m{highlight}\033[0m{end_context}"
+        self.errors.append(
+            ParseError(
+                f"{message}. Line {token.line}, Col: {token.col}.\n"
+                f"  {start_context}\033[4m{highlight}\033[0m{end_context}"
+            )
         )
-        if self.error_level == ErrorLevel.RAISE:
-            raise self.error
-        if self.error_level == ErrorLevel.WARN:
-            logging.error(self.error)
 
     def expression(self, exp_class, **kwargs):
         instance = exp_class(**kwargs)
@@ -326,10 +349,10 @@ class Parser:
         )
 
     def _parse_create(self):
-        temporary = self._match(TokenType.TEMPORARY)
         replace = self._match(TokenType.OR) and self._match(TokenType.REPLACE)
+        temporary = self._match(TokenType.TEMPORARY)
 
-        create_token = self._match(TokenType.TABLE, TokenType.VIEW) and self._prev
+        create_token = self._match_set((TokenType.TABLE, TokenType.VIEW)) and self._prev
 
         if not create_token:
             self.raise_error("Expected TABLE or View")
@@ -521,7 +544,7 @@ class Parser:
                 },
             )
 
-        return self._parse_union(this)
+        return self._parse_set_operations(this)
 
     def _parse_hint(self):
         if self._match(TokenType.HINT):
@@ -571,11 +594,11 @@ class Parser:
 
         while True:
             side = (
-                self._match(TokenType.LEFT, TokenType.RIGHT, TokenType.FULL)
+                self._match_set((TokenType.LEFT, TokenType.RIGHT, TokenType.FULL))
                 and self._prev
             )
             kind = (
-                self._match(TokenType.INNER, TokenType.OUTER, TokenType.CROSS)
+                self._match_set((TokenType.INNER, TokenType.OUTER, TokenType.CROSS))
                 and self._prev
             )
 
@@ -745,14 +768,26 @@ class Parser:
 
         return self.expression(exp.Limit, this=self._parse_number())
 
-    def _parse_union(self, this):
-        if not self._match(TokenType.UNION):
+    def _parse_set_operations(self, this):
+        if not self._match_set(self.SET_OPERATIONS):
             return this
 
-        distinct = not self._match(TokenType.ALL)
+        token_type = self._prev.token_type
+
+        if token_type == TokenType.UNION:
+            return self.expression(
+                exp.Union,
+                this=this,
+                distinct=self._match(TokenType.DISTINCT)
+                or not self._match(TokenType.ALL),
+                expression=self._parse_select(),
+            )
 
         return self.expression(
-            exp.Union, this=this, expression=self._parse_select(), distinct=distinct
+            exp.Except if token_type == TokenType.EXCEPT else exp.Intersect,
+            this=this,
+            distinct=self._match(TokenType.DISTINCT),
+            expression=self._parse_select(),
         )
 
     def _parse_expression(self):
@@ -854,7 +889,7 @@ class Parser:
         return this
 
     def _parse_types(self):
-        if self._match(TokenType.TIMESTAMP, TokenType.TIMESTAMPTZ):
+        if self._match_set(self.TIMESTAMPS):
             tz = self._match(TokenType.WITH)
             self._match(TokenType.WITHOUT)
             self._match(TokenType.TIME)
@@ -1109,7 +1144,7 @@ class Parser:
         order = self._parse_order()
 
         spec = None
-        kind = self._match(TokenType.ROWS, TokenType.RANGE) and self._prev.text
+        kind = self._match_set((TokenType.ROWS, TokenType.RANGE)) and self._prev.text
 
         if kind:
             self._match(TokenType.BETWEEN)
@@ -1138,11 +1173,11 @@ class Parser:
 
         return {
             "value": (
-                self._match(TokenType.UNBOUNDED, TokenType.CURRENT_ROW)
+                self._match_set((TokenType.UNBOUNDED, TokenType.CURRENT_ROW))
                 and self._prev.text
             )
             or self._parse_bitwise(),
-            "side": self._match(TokenType.PRECEDING, TokenType.FOLLOWING)
+            "side": self._match_set((TokenType.PRECEDING, TokenType.FOLLOWING))
             and self._prev.text,
         }
 
@@ -1222,8 +1257,15 @@ class Parser:
 
         return this
 
-    def _match(self, *types):
-        return self._match_set(types)
+    def _match(self, token_type):
+        if not self._curr:
+            return None
+
+        if self._curr.token_type == token_type:
+            self._advance()
+            return True
+
+        return None
 
     def _match_set(self, types):
         if not self._curr:
